curvelets.reference package
===========================

.. automodule:: curvelets.reference
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

curvelets.reference.udct module
-------------------------------

.. automodule:: curvelets.reference.udct
   :members:
   :undoc-members:
   :show-inheritance:

curvelets.reference.udctmdwin module
------------------------------------

.. automodule:: curvelets.reference.udctmdwin
   :members:
   :undoc-members:
   :show-inheritance:
